@@ -6,8 +6,8 @@ import mycli.sqlexecute
 
 @pytest.fixture(scope="function")
 def connection():
-    create_db('_test_db')
-    connection = db_connection('_test_db')
+    create_db('mycli_test_db')
+    connection = db_connection('mycli_test_db')
     yield connection
 
     connection.close()
@@ -22,7 +22,7 @@ def cursor(connection):
 @pytest.fixture
 def executor(connection):
     return mycli.sqlexecute.SQLExecute(
-        database='_test_db', user=USER,
+        database='mycli_test_db', user=USER,
         host=HOST, password=PASSWORD, port=PORT, socket=None, charset=CHARSET,
         local_infile=False, ssl=None, ssh_user=SSH_USER, ssh_host=SSH_HOST,
         ssh_port=SSH_PORT, ssh_password=None, ssh_key_filename=None
