@@ -2,7 +2,7 @@ import os
 import stat
 import tempfile
 from time import time
-from mock import patch
+from unittest.mock import patch
 
 import pytest
 from pymysql import ProgrammingError
@@ -49,7 +49,8 @@ def test_editor_command():
     assert mycli.packages.special.get_filename(r'\e filename') == "filename"
 
     os.environ['EDITOR'] = 'true'
-    mycli.packages.special.open_external_editor(r'select 1') == "select 1"
+    os.environ['VISUAL'] = 'true'
+    mycli.packages.special.open_external_editor(sql=r'select 1') == "select 1"
 
 
 def test_tee_command():
@@ -93,9 +94,8 @@ def test_once_command():
     with pytest.raises(TypeError):
         mycli.packages.special.execute(None, u"\\once")
 
-    mycli.packages.special.execute(None, u"\\once /proc/access-denied")
     with pytest.raises(OSError):
-        mycli.packages.special.write_once(u"hello world")
+        mycli.packages.special.execute(None, u"\\once /proc/access-denied")
 
     mycli.packages.special.write_once(u"hello world")  # write without file set
     with tempfile.NamedTemporaryFile() as f:
@@ -104,9 +104,24 @@ def test_once_command():
         assert f.read() == b"hello world\n"
 
         mycli.packages.special.execute(None, u"\\once -o " + f.name)
-        mycli.packages.special.write_once(u"hello world")
+        mycli.packages.special.write_once(u"hello world line 1")
+        mycli.packages.special.write_once(u"hello world line 2")
         f.seek(0)
-        assert f.read() == b"hello world\n"
+        assert f.read() == b"hello world line 1\nhello world line 2\n"
+
+
+def test_pipe_once_command():
+    with pytest.raises(IOError):
+        mycli.packages.special.execute(None, u"\\pipe_once")
+
+    with pytest.raises(OSError):
+        mycli.packages.special.execute(
+            None, u"\\pipe_once /proc/access-denied")
+
+    mycli.packages.special.execute(None, u"\\pipe_once wc")
+    mycli.packages.special.write_once(u"hello world")
+    mycli.packages.special.unset_pipe_once_if_written()
+    # how to assert on wc output?
 
 
 def test_parseargfile():
